module.exports = defineTest({
	description: 'treeshakes undefined variable literals'
});
